@@ -23,9 +23,9 @@
         iresc <- 0
     if (!is.null(before)) {
         if (is.unsorted(before)) 
-            stop("`before' must be sorted")
+            stop("'before' must be sorted")
         if (length(before) != length(after)) 
-            stop("`before' and `after' must have same lengths")
+            stop("'before' and 'after' must have same lengths")
         for (i in 1:nr) {
             tmp <- veg[i, ] > 0
             veg[i, tmp] <- approx(before, after, veg[i, tmp], 
