@@ -11,8 +11,14 @@
     image(z, axes = FALSE, col = col, ...)
     box()
     lines(x$smooth$x, 1 - x$smooth$y)
-    if (names) {
-        axis(3, at = seq(0,1,len=ncol(x$u)), labels=colnames(x$u), las=2, ...)
-        axis(2, at = seq(1,0,len=nrow(x$u)), labels=rownames(x$u), las=2,...)
+    if (length(names) == 1)
+        names <- rep(names, 2)
+    if (names[1]) {
+        axis(2, at = seq(1, 0, len = nrow(x$u)), labels = rownames(x$u),
+            las = 2, ...)
+    }
+    if (names[2]) {
+        axis(3, at = seq(0, 1, len = ncol(x$u)), labels = colnames(x$u),
+            las = 2, ...)
     }
 }
